@@ -45,6 +45,11 @@
 #'   [tidyselect::one_of()], [tidyselect::all_of()], and
 #'   [tidyselect::any_of()]
 #'
+#' Note that using [tidyselect::everything()] or any of the other `tidyselect`
+#' functions aren't restricted to predictors. They will thus select outcomes,
+#' ID, and predictor columns alike. This is why these functions should be used
+#' with care, and why [tidyselect::everything()] likely isn't what you need.
+#' 
 #' For example:
 #'
 #' \preformatted{
@@ -123,7 +128,7 @@ NULL
 #'
 #' This is a developer tool that is only useful for creating new recipes steps.
 #'
-#' @inheritParams ellipsis::dots_empty
+#' @inheritParams rlang::args_dots_empty
 #'
 #' @param quos A list of quosures describing the selection. This is generally
 #'   the `...` argument of your step function, captured with [rlang::enquos()]
@@ -172,7 +177,7 @@ NULL
 #' recipes_eval_select(quos, scat, info)
 recipes_eval_select <- function(quos, data, info, ..., allow_rename = FALSE,
                                 check_case_weights = TRUE, call = caller_env()) {
-  ellipsis::check_dots_empty()
+  check_dots_empty()
 
   if (rlang::is_missing(quos)) {
     cli::cli_abort("Argument {.arg quos} is missing, with no default.")
@@ -194,6 +199,17 @@ recipes_eval_select <- function(quos, data, info, ..., allow_rename = FALSE,
 
   expr <- expr(c(!!!quos))
 
+  if ((!allow_rename) && any(names(expr) != "")) {
+    offenders <- names(expr)
+    offenders <- offenders[offenders != ""]
+
+    cli::cli_abort(
+      "The following argument{?s} {?was/were} specified but do not exist: \\
+      {.arg {offenders}}.", 
+      call = call
+  )
+  }
+
   sel <- tidyselect::eval_select(
     expr = expr,
     data = data,
