@@ -1,9 +1,10 @@
-#' Moving Window Functions
+#' Moving window functions
 #'
 #' `step_window()` creates a *specification* of a recipe step that will create
 #' new columns that are the results of functions that compute statistics across
 #' moving windows.
 #'
+#' @inheritParams step_classdist
 #' @inheritParams step_center
 #' @inheritParams step_pca
 #' @param role For model terms created by this step, what analysis
@@ -44,9 +45,15 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected), `statistic` (the
-#' summary function name), and `size` is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `statistic`, `size` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{statistic}{character, the summary function name}
+#'   \item{size}{integer, window size}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_window"
@@ -82,7 +89,7 @@
 #'   )
 #' rec <- prep(rec, training = sim_dat)
 #'
-#' smoothed_dat <- bake(rec, sim_dat, everything())
+#' smoothed_dat <- bake(rec, sim_dat)
 #'
 #' ggplot(data = sim_dat, aes(x = x1, y = y1)) +
 #'   geom_point() +
@@ -99,7 +106,7 @@
 #' rec <- recipe(y1 + y2 + original ~ x1 + x2 + x3, data = sim_dat) %>%
 #'   step_window(starts_with("y"))
 #' rec <- prep(rec, training = sim_dat)
-#' smoothed_dat <- bake(rec, sim_dat, everything())
+#' smoothed_dat <- bake(rec, sim_dat)
 #' ggplot(smoothed_dat, aes(x = original, y = y1)) +
 #'   geom_point() +
 #'   theme_bw()
@@ -118,41 +125,30 @@ step_window <-
            id = rand_id("window")) {
     if (!is_call(statistic) &&
       (!(statistic %in% roll_funs) | length(statistic) != 1)) {
-      rlang::abort(
-        paste0(
-          "`statistic` should be one of: ",
-          paste0("'", roll_funs, "'", collapse = ", ")
-        )
+      cli::cli_abort(
+        "{.arg statistic} should be one of: {.or {.val {roll_funs}}}."
       )
     }
 
     ## ensure size is odd, integer, and not too small
     if (!is_tune(size)) {
-      if (is.na(size) | is.null(size)) {
-        rlang::abort("`size` needs a value.")
-      }
+      check_number_decimal(size, min = 0)
 
       if (!is.integer(size)) {
         tmp <- size
         size <- as.integer(size)
         if (!isTRUE(all.equal(tmp, size))) {
-          rlang::warn(
-            paste0(
-              "`size` was not an integer (",
-              tmp,
-              ") and was ",
-              "converted to ",
-              size,
-              "."
-            )
+          cli::cli_warn(
+            "{.arg size} was not an integer ({tmp}) and was converted to \\
+            {size}."
           )
         }
       }
       if (size %% 2 == 0) {
-        rlang::abort("`size` should be odd.")
+        cli::cli_abort("{.arg size} should be odd, not {size}.")
       }
       if (size < 3) {
-        rlang::abort("`size` should be at least 3.")
+        cli::cli_abort("{.arg size} should be at least 3, not {size}.")
       }
     }
     add_step(
@@ -201,12 +197,10 @@ prep.step_window <- function(x, training, info = NULL, ...) {
 
   if (!is.null(x$names)) {
     if (length(x$names) != length(col_names)) {
-      rlang::abort(
-        paste0(
-          "There were ", length(col_names), " term(s) selected but ",
-          length(x$names), " values for the new features ",
-          "were passed to `names`."
-        )
+      cli::cli_abort(
+        "There were {length(col_names)} term{?s} selected but \\
+        {length(x$names)} value{?s} for the new features {?was/were} passed \\
+        to {.arg names}."
       )
     }
   }
@@ -233,7 +227,7 @@ roller <- function(x, stat = "mean", window = 3L, na_rm = TRUE) {
 
   gap <- floor(window / 2)
   if (m - window <= 2) {
-    rlang::abort("The window is too large.")
+    cli::cli_abort("The window is too large.")
   }
 
   ## stats for centered window
@@ -286,7 +280,7 @@ bake.step_window <- function(object, new_data, ...) {
   new_data
 }
 
-
+#' @export
 print.step_window <-
   function(x, width = max(20, options()$width - 28), ...) {
     title <- glue("Moving {x$size}-point {x$statistic} on ")
